import { useParams } from 'solid-start';
import User from '~/components/user';
import { createEffect, createSignal, Show } from 'solid-js';
import { adminCredentials, CheckCredentials } from '~/components/credentials';
import { get } from '~/lib/get';
import { createServerAction$ } from 'solid-start/server';
import { readConfig } from '~/server-only-lib/read-config';
import { createTransport } from 'nodemailer';
import { resolve } from 'path';
import hbs from 'nodemailer-express-handlebars';

export const [sendingInvitation, sendInvitation] = createServerAction$(
  async (args: {
    id: string;
    mail: string;
    webInvitation: string;
    appInvitation: string;
  }) => {
    const { id, mail, webInvitation, appInvitation } = args;
    const { credentials, mailer } = readConfig();
    const transporter = createTransport(mailer);

    const handlebarOptions = {
      viewEngine: {
        partialsDir: resolve('src/mail-template/'),
        defaultLayout: false,
      },
      viewPath: resolve('src/mail-template/'),
    };
    transporter.use('compile', hbs(handlebarOptions));

    const code = [...Array(6)].map((_) => (Math.random() * 10) | 0).join('');

    const mailOptions = {
      from: '"Dyomedea app" <app@dyomedea.com>', // sender address
      to: mail, // list of receivers
      subject: "Invitation à configurer l'application Dyomedea.",
      template: 'invitation', // the name of the template file i.e email.handlebars
      context: {
        id,
        webInvitation,
        appInvitation,
      },
    };

    await transporter.sendMail(mailOptions);
  }
);

export default () => {
  const { id } = useParams();
  const [user, setUser] = createSignal();

  createEffect(async () => {
    if (!user()) {
      setUser(await get(id));
      console.log({
        caller: '/routes/user/[id].ts / createEffect',
        user: user(),
        adminCredentials: adminCredentials(),
      });
    }
  });

  return (
    <main>
      <h1>User</h1>
      <CheckCredentials>
        <Show when={!!user()}>
          <User values={user} />
        </Show>
      </CheckCredentials>
    </main>
  );
};
